#!/usr/bin/env python
from __future__ import absolute_import, division, print_function
import httplib
import subprocess
import time
from contextlib import closing
 
LOG_FILENAME = 'logfile.log'
MOBILE_DEVICE_IP = '192.168.1.21'
LIGHT_SERVER_IP = '192.168.1.26'
CHECK_INTERVAL = 10  # sekunden
AWAY_CHECK_INTERVAL = 10  # Wartezeit abwesend
AN, AUS = True, False
 
 
def log(message):
    with open(LOG_FILENAME, "a") as logfile:
        logfile.write(
            '{0}: {1}\n'.format(time.strftime('%d.%m.%Y %H:%M:%S'), message)
        )
 
 
def presence():
    return subprocess.call(['ping', '-c', '1', MOBILE_DEVICE_IP]) == 0
 
 
def waiting_for_presence():
    while not presence():
        time.sleep(CHECK_INTERVAL)
 
 
def waiting_for_absence():
    away_count = 0
    while away_count < 10:
        if not presence():
            away_count += 1
            time.sleep(AWAY_CHECK_INTERVAL)
        else:
            away_count = 0
            time.sleep(CHECK_INTERVAL)
 
 
def schalte_licht(state):
    with closing(httplib.HTTPConnection(LIGHT_SERVER_IP, 80)) as connection:
        connection.connect()
        connection.request(
            'GET', '/control?key={0}'.format(106 if state else 107)
        )
        log('Licht {0}geschaltet'.format('ein' if state else 'aus'))
 
 
def main():
    while True:
        waiting_for_presence()
        schalte_licht(AN)
        waiting_for_absence()
        schalte_licht(AUS)
 
 
if __name__ == '__main__':
    main()